@@ -76,6 +76,8 @@ class OptimalBucketer(BaseBucketer):
                     most_risky: Missing values are put into the bucket containing the largest percentage of Class 1.
                     least_risky: Missing values are put into the bucket containing the largest percentage of Class 0.
                     most_frequent: Missing values are put into the most common bucket.
+                    neutral: Missing values are put into the bucket with WoE closest to 0.
+                    similar: Missing values are put into the bucket with WoE closest to the bucket with only missing values.
                 If a dict, it must be of the following format:
                     {"<column name>": <bucket_number>}
                     This bucket number is where we will put the missing values.
@@ -172,7 +174,7 @@ class OptimalBucketer(BaseBucketer):
                 splits = binner.splits
 
             # Deal with missing values
-            if self.missing_treatment in ["separate", "most_frequent", "most_risky", "least_risky"]:
+            if self.missing_treatment in ["separate", "most_frequent", "most_risky", "least_risky", "neutral", "similar"]:
                 missing_bucket = None
             if isinstance(self.missing_treatment, dict):
                 missing_bucket = self.missing_treatment.get(feature)
@@ -196,7 +198,7 @@ class OptimalBucketer(BaseBucketer):
                 bucket_mapping=features_bucket_mapping_.get(feature),
             )
 
-            if self.missing_treatment in ["most_frequent", "most_risky", "least_risky"]:
+            if self.missing_treatment in ["most_frequent", "most_risky", "least_risky", "neutral", "similar"]:
                 missing_bucket = self._find_missing_bucket(feature=feature)
                 # Repeat above procedure now we know the bucket distribution
                 features_bucket_mapping_[feature] = BucketMapping(
@@ -275,6 +277,8 @@ class EqualWidthBucketer(BaseBucketer):
                     most_risky: Missing values are put into the bucket containing the largest percentage of Class 1.
                     least_risky: Missing values are put into the bucket containing the largest percentage of Class 0.
                     most_frequent: Missing values are put into the most common bucket.
+                    neutral: Missing values are put into the bucket with WoE closest to 0.
+                    similar: Missing values are put into the bucket with WoE closest to the bucket with only missing values.
                 If a dict, it must be of the following format:
                     {"<column name>": <bucket_number>}
                     This bucket number is where we will put the missing values.
@@ -326,7 +330,7 @@ class EqualWidthBucketer(BaseBucketer):
                 boundaries = boundaries.tolist()
 
             # Deal with missing values
-            if self.missing_treatment in ["separate", "most_frequent", "most_risky", "least_risky"]:
+            if self.missing_treatment in ["separate", "most_frequent", "most_risky", "least_risky", "neutral", "similar"]:
                 missing_bucket = None
             if isinstance(self.missing_treatment, dict):
                 missing_bucket = self.missing_treatment.get(feature)
@@ -348,7 +352,7 @@ class EqualWidthBucketer(BaseBucketer):
                 bucket_mapping=features_bucket_mapping_.get(feature),
             )
 
-            if self.missing_treatment in ["most_frequent", "most_risky", "least_risky"]:
+            if self.missing_treatment in ["most_frequent", "most_risky", "least_risky", "neutral", "similar"]:
                 missing_bucket = self._find_missing_bucket(feature=feature)
 
                 assert isinstance(missing_bucket, int)
@@ -428,6 +432,8 @@ class AgglomerativeClusteringBucketer(BaseBucketer):
                     most_risky: Missing values are put into the bucket containing the largest percentage of Class 1.
                     least_risky: Missing values are put into the bucket containing the largest percentage of Class 0.
                     most_frequent: Missing values are put into the most common bucket.
+                    neutral: Missing values are put into the bucket with WoE closest to 0.
+                    similar: Missing values are put into the bucket with WoE closest to the bucket with only missing values.
                 If a dict, it must be of the following format:
                     {"<column name>": <bucket_number>}
                     This bucket number is where we will put the missing values.
@@ -489,7 +495,7 @@ class AgglomerativeClusteringBucketer(BaseBucketer):
                 boundaries = boundaries.tolist()
 
             # Deal with missing values
-            if self.missing_treatment in ["separate", "most_frequent", "most_risky", "least_risky"]:
+            if self.missing_treatment in ["separate", "most_frequent", "most_risky", "least_risky", "neutral", "similar"]:
                 missing_bucket = None
             if isinstance(self.missing_treatment, dict):
                 missing_bucket = self.missing_treatment.get(feature)
@@ -511,7 +517,7 @@ class AgglomerativeClusteringBucketer(BaseBucketer):
                 bucket_mapping=features_bucket_mapping_.get(feature),
             )
 
-            if self.missing_treatment in ["most_frequent", "most_risky", "least_risky"]:
+            if self.missing_treatment in ["most_frequent", "most_risky", "least_risky", "neutral", "similar"]:
                 missing_bucket = self._find_missing_bucket(feature=feature)
                 # Repeat above procedure now we know the bucket distribution
                 features_bucket_mapping_[feature] = BucketMapping(
@@ -583,6 +589,8 @@ class EqualFrequencyBucketer(BaseBucketer):
                     most_risky: Missing values are put into the bucket containing the largest percentage of Class 1.
                     least_risky: Missing values are put into the bucket containing the largest percentage of Class 0.
                     most_frequent: Missing values are put into the most common bucket.
+                    neutral: Missing values are put into the bucket with WoE closest to 0.
+                    similar: Missing values are put into the bucket with WoE closest to the bucket with only missing values.
                 If a dict, it must be of the following format:
                     {"<column name>": <bucket_number>}
                     This bucket number is where we will put the missing values..
@@ -643,7 +651,7 @@ class EqualFrequencyBucketer(BaseBucketer):
                 boundaries = boundaries.tolist()
 
             # Deal with missing values
-            if self.missing_treatment in ["separate", "most_frequent", "most_risky", "least_risky"]:
+            if self.missing_treatment in ["separate", "most_frequent", "most_risky", "least_risky", "neutral", "similar"]:
                 missing_bucket = None
             if isinstance(self.missing_treatment, dict):
                 missing_bucket = self.missing_treatment.get(feature)
@@ -665,7 +673,7 @@ class EqualFrequencyBucketer(BaseBucketer):
                 bucket_mapping=features_bucket_mapping_.get(feature),
             )
 
-            if self.missing_treatment in ["most_frequent", "most_risky", "least_risky"]:
+            if self.missing_treatment in ["most_frequent", "most_risky", "least_risky", "neutral", "similar"]:
                 missing_bucket = self._find_missing_bucket(feature=feature)
 
                 # Repeat above procedure now we know the bucket distribution
@@ -762,6 +770,8 @@ class DecisionTreeBucketer(BaseBucketer):
                     most_risky: Missing values are put into the bucket containing the largest percentage of Class 1.
                     least_risky: Missing values are put into the bucket containing the largest percentage of Class 0.
                     most_frequent: Missing values are put into the most common bucket.
+                    neutral: Missing values are put into the bucket with WoE closest to 0.
+                    similar: Missing values are put into the bucket with WoE closest to the bucket with only missing values.
                 If a dict, it must be of the following format:
                     {"<column name>": <bucket_number>}
                     This bucket number is where we will put the missing values.
@@ -842,7 +852,7 @@ class DecisionTreeBucketer(BaseBucketer):
                 splits = []
 
             # Deal with missing values
-            if self.missing_treatment in ["separate", "most_frequent", "most_risky", "least_risky"]:
+            if self.missing_treatment in ["separate", "most_frequent", "most_risky", "least_risky", "neutral", "similar"]:
                 missing_bucket = None
             if isinstance(self.missing_treatment, dict):
                 missing_bucket = self.missing_treatment.get(feature)
@@ -864,7 +874,7 @@ class DecisionTreeBucketer(BaseBucketer):
                 bucket_mapping=features_bucket_mapping_.get(feature),
             )
 
-            if self.missing_treatment in ["most_frequent", "most_risky", "least_risky"]:
+            if self.missing_treatment in ["most_frequent", "most_risky", "least_risky", "neutral", "similar"]:
                 missing_bucket = self._find_missing_bucket(feature=feature)
                 # Repeat above procedure now we know the bucket distribution
                 features_bucket_mapping_[feature] = BucketMapping(
@@ -965,6 +975,8 @@ class OrdinalCategoricalBucketer(BaseBucketer):
                     most_risky: Missing values are put into the bucket containing the largest percentage of Class 1.
                     least_risky: Missing values are put into the bucket containing the largest percentage of Class 0.
                     most_frequent: Missing values are put into the most common bucket.
+                    neutral: Missing values are put into the bucket with WoE closest to 0.
+                    similar: Missing values are put into the bucket with WoE closest to the bucket with only missing values.
                 If a dict, it must be of the following format:
                     {"<column name>": <bucket_number>}
                     This bucket number is where we will put the missing values.
@@ -1050,7 +1062,7 @@ class OrdinalCategoricalBucketer(BaseBucketer):
             mapping = dict(zip(normalized_counts.index, range(0, len(normalized_counts))))
 
             # Deal with missing values
-            if self.missing_treatment in ["separate", "most_frequent", "most_risky", "least_risky"]:
+            if self.missing_treatment in ["separate", "most_frequent", "most_risky", "least_risky", "neutral", "similar"]:
                 missing_bucket = None
             if isinstance(self.missing_treatment, dict):
                 missing_bucket = self.missing_treatment.get(feature)
@@ -1068,7 +1080,7 @@ class OrdinalCategoricalBucketer(BaseBucketer):
                 X, y, column=feature, bucket_mapping=features_bucket_mapping_.get(feature)
             )
 
-            if self.missing_treatment in ["most_frequent", "most_risky", "least_risky"]:
+            if self.missing_treatment in ["most_frequent", "most_risky", "least_risky", "neutral", "similar"]:
                 missing_bucket = self._find_missing_bucket(feature=feature)
                 # Repeat above procedure now we know the bucket distribution
                 features_bucket_mapping_[feature] = BucketMapping(
@@ -1139,6 +1151,8 @@ class AsIsCategoricalBucketer(BaseBucketer):
                     most_risky: Missing values are put into the bucket containing the largest percentage of Class 1.
                     least_risky: Missing values are put into the bucket containing the largest percentage of Class 0.
                     most_frequent: Missing values are put into the most common bucket.
+                    neutral: Missing values are put into the bucket with WoE closest to 0.
+                    similar: Missing values are put into the bucket with WoE closest to the bucket with only missing values.
                 If a dict, it must be of the following format:
                     {"<column name>": <bucket_number>}
                     This bucket number is where we will put the missing values.
@@ -1182,7 +1196,7 @@ class AsIsCategoricalBucketer(BaseBucketer):
             mapping = dict(zip(unq, range(0, len(unq))))
 
             # Deal with missing values
-            if self.missing_treatment in ["separate", "most_frequent", "most_risky", "least_risky"]:
+            if self.missing_treatment in ["separate", "most_frequent", "most_risky", "least_risky", "neutral", "similar"]:
                 missing_bucket = None
             if isinstance(self.missing_treatment, dict):
                 missing_bucket = self.missing_treatment.get(feature)
@@ -1200,7 +1214,7 @@ class AsIsCategoricalBucketer(BaseBucketer):
                 X, y, column=feature, bucket_mapping=features_bucket_mapping_.get(feature)
             )
 
-            if self.missing_treatment in ["most_frequent", "most_risky", "least_risky"]:
+            if self.missing_treatment in ["most_frequent", "most_risky", "least_risky", "neutral", "similar"]:
                 missing_bucket = self._find_missing_bucket(feature=feature)
 
                 # Repeat above procedure now we know the bucket distribution
@@ -1274,6 +1288,8 @@ class AsIsNumericalBucketer(BaseBucketer):
                     most_risky: Missing values are put into the bucket containing the largest percentage of Class 1.
                     least_risky: Missing values are put into the bucket containing the largest percentage of Class 0.
                     most_frequent: Missing values are put into the most common bucket.
+                    neutral: Missing values are put into the bucket with WoE closest to 0.
+                    similar: Missing values are put into the bucket with WoE closest to the bucket with only missing values.
                 If a dict, it must be of the following format:
                     {"<column name>": <bucket_number>}
                     This bucket number is where we will put the missing values..
@@ -1321,7 +1337,7 @@ class AsIsNumericalBucketer(BaseBucketer):
                 raise NotPreBucketedError(msg)
 
             # Deal with missing values
-            if self.missing_treatment in ["separate", "most_frequent", "most_risky", "least_risky"]:
+            if self.missing_treatment in ["separate", "most_frequent", "most_risky", "least_risky", "neutral", "similar"]:
                 missing_bucket = None
             if isinstance(self.missing_treatment, dict):
                 missing_bucket = self.missing_treatment.get(feature)
@@ -1343,7 +1359,7 @@ class AsIsNumericalBucketer(BaseBucketer):
                 bucket_mapping=features_bucket_mapping_.get(feature),
             )
 
-            if self.missing_treatment in ["most_frequent", "most_risky", "least_risky"]:
+            if self.missing_treatment in ["most_frequent", "most_risky", "least_risky", "neutral", "similar"]:
                 missing_bucket = self._find_missing_bucket(feature=feature)
                 # Repeat above procedure now we know the bucket distribution
                 features_bucket_mapping_[feature] = BucketMapping(
